@@ -119,7 +119,7 @@ def _update_file_mounts(
                 '"{remote}: {local}" has been detected in the file mounts.\n'
                 'Anyscale needs to sync the local project directory "{proj}" '
                 'with "{remote}" in the cluster.\nCan this file mount be replaced for '
-                "this command?\nThis action will not change your session "
+                "this command?\nThis action will not change your cluster "
                 "configuration file.".format(
                     remote=remote_path, local=local_path, proj=project_root_dir,
                 ),
