@@ -6,7 +6,7 @@ from typing import Optional
 
 import click
 
-from anyscale.api import get_anyscale_api_client
+from anyscale.authenticate import get_auth_api_client
 from anyscale.formatters import common_formatter
 from anyscale.sdk.anyscale_client import CreateProject, UpdateProject
 
@@ -30,7 +30,7 @@ def projects() -> None:
 def list_projects(count: int, paging_token: Optional[str],) -> None:
     """Lists all non-deleted projects that the user has access to. """
 
-    api_client = get_anyscale_api_client()
+    api_client = get_auth_api_client().anyscale_api_client
     response = api_client.list_projects(count=count, paging_token=paging_token)
 
     print(common_formatter.prettify_json(response.to_dict()))
@@ -41,7 +41,7 @@ def list_projects(count: int, paging_token: Optional[str],) -> None:
 def get_project(project_id: str) -> None:
     """Get details about the Project with id PROJECT_ID"""
 
-    api_client = get_anyscale_api_client()
+    api_client = get_auth_api_client().anyscale_api_client
     response = api_client.get_project(project_id)
 
     print(common_formatter.prettify_json(response.to_dict()))
@@ -63,7 +63,7 @@ def create_project(
 ) -> None:
     """Creates a Project with NAME, CLUSTER_CONFIG, and DESCRIPTION."""
 
-    api_client = get_anyscale_api_client()
+    api_client = get_auth_api_client().anyscale_api_client
     create_data = CreateProject(
         name=name, cluster_config=cluster_config, description=description
     )
@@ -94,7 +94,7 @@ def update_project(
     a field is not provided.
     """
 
-    api_client = get_anyscale_api_client()
+    api_client = get_auth_api_client().anyscale_api_client
     update_data = UpdateProject(cluster_config=cluster_config, description=description)
     response = api_client.update_project(project_id, update_data)
 
@@ -106,5 +106,5 @@ def update_project(
 def delete_project(project_id: str) -> None:
     """Delete the Project with id PROJECT_ID"""
 
-    api_client = get_anyscale_api_client()
+    api_client = get_auth_api_client().anyscale_api_client
     api_client.delete_project(project_id)
