@@ -73,3 +73,22 @@ def list(
 def terminate(job_id: Optional[str], name: Optional[str]) -> None:
     job_controller = JobController()
     job_controller.terminate(job_id=job_id, job_name=name)
+
+
+@job_cli.command(name="logs", help="Print the logs of a job.")
+@click.option("--job-id", "--id", required=False, help="Id of job.")
+@click.option("--name", "-n", required=False, help="Name of job.")
+@click.option(
+    "--follow",
+    "-f",
+    required=False,
+    default=False,
+    type=bool,
+    is_flag=True,
+    help="Whether to follow the log.",
+)
+def logs(job_id: Optional[str], name: Optional[str], follow: bool = False,) -> None:
+    job_controller = JobController()
+    job_controller.logs(
+        job_id=job_id, job_name=name, should_follow=follow,
+    )
