@@ -79,6 +79,7 @@ class PrepareClusterBlock:
         cluster_env_dict: Optional[CLUSTER_ENV_DICT_TYPE],
         cluster_env_revision: Optional[int],
         ray: Any,
+        log_output: bool = True,
     ):
         """
         Class to prepare a cluster (create and start if required) so it can be
@@ -101,11 +102,11 @@ class PrepareClusterBlock:
         self.cluster_env_revision = cluster_env_revision
         self._ray = ray
 
-        auth_api_client = get_auth_api_client()
+        auth_api_client = get_auth_api_client(log_output=log_output)
         self.api_client = auth_api_client.api_client
         self.anyscale_api_client = auth_api_client.anyscale_api_client
 
-        self.log = BlockLogger()
+        self.log = BlockLogger(log_output=log_output)
         self.block_label = "PrepareCluster"
         self.log.open_block(self.block_label, block_title="Preparing the cluster")
 
@@ -135,7 +136,7 @@ class PrepareClusterBlock:
             # already exists). Otherwise, we get the default build ID.
             if self.cluster_env_name or existing_terminated_cluster is None:
                 build_id = self._get_cluster_build(
-                    project_id, self.cluster_env_name, self.cluster_env_revision
+                    self.cluster_env_name, self.cluster_env_revision
                 ).id
             else:
                 build_id = existing_terminated_cluster.build_id
@@ -388,12 +389,8 @@ class PrepareClusterBlock:
         """
 
         start_required = True
-        cluster_list = self.api_client.list_sessions_api_v2_sessions_get(
-            project_id=project_id, active_only=False, name=cluster_name
-        ).results
-
-        cluster_exists = len(cluster_list) > 0
-        if not cluster_exists:
+        cluster = get_cluster(self.anyscale_api_client, project_id, cluster_name)
+        if not cluster:
             # Create a new cluster if there is no existing cluster with the given cluster_name
             self.log.info(
                 f"Cluster {BlockLogger.highlight(cluster_name)} does not exist. A new cluster will be created.",
@@ -416,7 +413,6 @@ class PrepareClusterBlock:
             ).result
         else:
             # Get the existing cluster and update the idle_timeout if required
-            cluster = cluster_list[0]
             if cluster.state == "Running":
                 start_required = self._validate_new_cluster_compute_and_env_match_existing_cluster(
                     project_id, cluster, print_warnings=False
@@ -483,7 +479,7 @@ class PrepareClusterBlock:
         Get the default cluster env build based on the local python and ray versions.
         """
         py_version = "".join(str(x) for x in sys.version_info[0:2])
-        if py_version not in ["36", "37", "38"]:
+        if py_version not in ["36", "37", "38", "39"]:
             raise ValueError(
                 "No default cluster env for py{}. Please use a version of python between 3.6 and 3.8.".format(
                     py_version
@@ -511,18 +507,13 @@ class PrepareClusterBlock:
             )
 
     def _get_cluster_build(
-        self,
-        project_id: str,
-        cluster_env_name: Optional[str],
-        cluster_env_revision: Optional[int],
+        self, cluster_env_name: Optional[str], cluster_env_revision: Optional[int],
     ) -> Build:
         """Returns the build of the cluster to be created.
         By default we return the default cluster env, unless the user overrides.
         """
         if cluster_env_name:
-            build = self._get_cluster_env_build(
-                project_id, cluster_env_name, cluster_env_revision
-            )
+            build = self._get_cluster_env_build(cluster_env_name, cluster_env_revision)
         else:
             try:
                 build = self._get_default_cluster_env_build()
@@ -541,7 +532,7 @@ class PrepareClusterBlock:
         return build
 
     def _get_cluster_env_build(
-        self, project_id: str, cluster_env_name: str, clust_env_revision: Optional[int]
+        self, cluster_env_name: str, clust_env_revision: Optional[int]
     ) -> Build:
         """
         Get the build for the specified cluster environment. If the cluster env revsion is
@@ -550,7 +541,7 @@ class PrepareClusterBlock:
         app_template_id = None
         cluster_environments = list_entities(
             self.anyscale_api_client.list_app_configs,
-            filters={"name_contains": cluster_env_name, "project_id": project_id},
+            filters={"name_contains": cluster_env_name},
         )
         for cluster_env in cluster_environments:
             if cluster_env.name == cluster_env_name:
@@ -762,9 +753,7 @@ class PrepareClusterBlock:
         Register compute template with a default name and return the compute template id."""
         created_template = self.api_client.create_compute_template_api_v2_compute_templates_post(
             create_compute_template=CreateComputeTemplate(
-                name="connect-autogenerated-config-{}".format(
-                    datetime.now().isoformat()
-                ),
+                name="autogenerated-config-{}".format(datetime.now().isoformat()),
                 project_id=project_id,
                 config=config_object,
                 anonymous=True,
@@ -895,7 +884,7 @@ class PrepareClusterBlock:
         cluster_name = running_cluster.name
         if self.cluster_env_name:
             overriding_build = self._get_cluster_build(
-                project_id, self.cluster_env_name, self.cluster_env_revision
+                self.cluster_env_name, self.cluster_env_revision
             )
             if overriding_build.id != running_cluster.build_id:
                 current_cluster_build = self.anyscale_api_client.get_build(
@@ -979,6 +968,7 @@ def create_prepare_cluster_block(
     cluster_env_dict: Optional[CLUSTER_ENV_DICT_TYPE],
     cluster_env_revision: Optional[int],
     ray: Any,
+    log_output: bool = True,
 ):
     """
     Function to get PrepareClusterBlock object. The PrepareClusterBlock object
@@ -1001,4 +991,5 @@ def create_prepare_cluster_block(
         cluster_env_dict=cluster_env_dict,
         cluster_env_revision=cluster_env_revision,
         ray=ray,
+        log_output=log_output,
     )
