@@ -5,16 +5,35 @@ Fetches data required and formats output for `anyscale cloud` commands.
 import ipaddress
 import json
 import os
+import time
 from typing import Any, Dict, Optional
 
 import boto3
-from click import ClickException, prompt
+import botocore.exceptions
+from click import ClickException, INT, prompt
 
+from anyscale.aws_iam_policies import (
+    AMAZON_CLOUDWATCH_FULL_ACCESS_POLICY_ARN,
+    AMAZON_EC2_FULL_ACCESS_POLICY_ARN,
+    AMAZON_IAM_FULL_ACCESS_POLICY_ARN,
+    AMAZON_ROUTE53_FULL_ACCESS_POLICY_ARN,
+    AMAZON_S3_FULL_ACCESS_POLIC_ARN,
+    AMAZON_VPC_FULL_ACCESS_POLICY_ARN,
+    ANYSCALE_IAM_ACCESS_POLICY_DOCUMENT,
+    ANYSCALE_IAM_ACCESS_POLICY_NAME,
+    EKS_FULL_ACCESS_POLICY_DOCUMENT,
+    EKS_FULL_ACCESS_POLICY_NAME,
+)
 from anyscale.cli_logger import BlockLogger
-from anyscale.client.openapi_client.models.cloud_config import CloudConfig
-from anyscale.client.openapi_client.models.write_cloud import WriteCloud
+from anyscale.client.openapi_client.models import (
+    Cloud,
+    CloudConfig,
+    CloudProviders,
+    CloudResponse,
+    WriteCloud,
+)
 from anyscale.cloud import get_cloud_id_and_name, get_cloud_json_from_id
-import anyscale.conf
+from anyscale.conf import ANYSCALE_IAM_ROLE_NAME
 from anyscale.controllers.base_controller import BaseController
 from anyscale.formatters import clouds_formatter
 from anyscale.util import (  # pylint:disable=private-import
@@ -25,9 +44,14 @@ from anyscale.util import (  # pylint:disable=private-import
     confirm,
     get_available_regions,
     launch_gcp_cloud_setup,
+    number_of_external_ids_in_policy,
 )
 
 
+ROLE_CREATION_RETRIES = 30
+ROLE_CREATION_INTERVAL_SECONDS = 1
+
+
 class CloudController(BaseController):
     def __init__(
         self, log: BlockLogger = BlockLogger(), initialize_auth_api_client: bool = True
@@ -141,6 +165,7 @@ class CloudController(BaseController):
     def setup_cloud(
         self,
         is_aioa: bool,
+        is_k8s: bool,
         provider: str,
         region: Optional[str],
         name: str,
@@ -161,7 +186,16 @@ class CloudController(BaseController):
             # If the region is blank, change it to the default for AWS.
             if region is None:
                 region = "us-west-2"
-            self.setup_aws(region=region, name=name, yes=yes)
+            regions_available = get_available_regions()
+            if region not in regions_available:
+                raise ClickException(
+                    f"Region '{region}' is not available. Regions available are: "
+                    f"{', '.join(map(repr, regions_available))}"
+                )
+            if is_k8s:
+                self.setup_aws_k8s_cloud(region=region, name=name, yes=yes)
+            else:
+                self.setup_aws(region=region, name=name, yes=yes)
         elif provider == "gcp":
             # If the region is blank, change it to the default for GCP.
             if region is None:
@@ -184,7 +218,7 @@ class CloudController(BaseController):
                     "\tIf not specified, the 'Anyscale' folder will be created directly under the organization.\n"
                     "Folder ID (numerals only)",
                     default="",
-                    type=int,
+                    type=INT,
                     show_default=False,
                 )
 
@@ -235,11 +269,6 @@ class CloudController(BaseController):
         from ray.autoscaler._private.aws.config import DEFAULT_RAY_IAM_ROLE
 
         os.environ["AWS_DEFAULT_REGION"] = region
-        regions_available = get_available_regions()
-        if region not in regions_available:
-            raise ClickException(
-                f"Region '{region}' is not available. Regions availables are {regions_available}"
-            )
 
         confirm(
             "\nYou are about to give anyscale full access to EC2 and IAM in your AWS account.\n\n"
@@ -274,20 +303,21 @@ class CloudController(BaseController):
             },
         }
 
-        role = _get_role(anyscale.conf.ANYSCALE_IAM_ROLE_NAME, region)
+        role = _get_role(ANYSCALE_IAM_ROLE_NAME, region)
 
+        role_exists = role is not None
         if role is None:
             iam = _resource("iam", region)
             iam.create_role(
-                RoleName=anyscale.conf.ANYSCALE_IAM_ROLE_NAME,
+                RoleName=ANYSCALE_IAM_ROLE_NAME,
                 AssumeRolePolicyDocument=json.dumps(anyscale_aws_iam_role_policy),
             )
-            role = _get_role(anyscale.conf.ANYSCALE_IAM_ROLE_NAME, region)
+            role = _get_role(ANYSCALE_IAM_ROLE_NAME, region)
 
         assert role is not None, "Failed to create IAM role!"
 
-        role.attach_policy(PolicyArn="arn:aws:iam::aws:policy/AmazonEC2FullAccess")
-        role.attach_policy(PolicyArn="arn:aws:iam::aws:policy/IAMFullAccess")
+        role.attach_policy(PolicyArn=AMAZON_EC2_FULL_ACCESS_POLICY_ARN)
+        role.attach_policy(PolicyArn=AMAZON_IAM_FULL_ACCESS_POLICY_ARN)
 
         self.log.info(f"Using IAM role {role.arn}")
 
@@ -297,6 +327,14 @@ class CloudController(BaseController):
             )
         )
 
+        # NOTE: If we are modifying an existing Role that does not have External IDs, we
+        # cannot add an ExternalID check to the policy because it could break old clouds.
+        if (
+            role_exists
+            and number_of_external_ids_in_policy(role.assume_role_policy_document) == 0
+        ):
+            return
+
         # NOTE: We update this _after_ cloud creation because this External ID MUST
         # come from Anyscale, not the customer. We are using the `cloud_id` as it is unique per cloud.
         # https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_create_for-user_externalid.html
@@ -328,7 +366,7 @@ class CloudController(BaseController):
             role = _get_role(role_name, region)
 
         # Modified permissions from Ray (no EC2FullAccess)
-        role.attach_policy(PolicyArn="arn:aws:iam::aws:policy/AmazonS3FullAccess")
+        role.attach_policy(PolicyArn=AMAZON_S3_FULL_ACCESS_POLIC_ARN)
 
         # Also attach a role to allow it to launch more nodes with itself
         role.Policy("PassRoleToSelf").put(
@@ -347,6 +385,111 @@ class CloudController(BaseController):
             )
         )
 
+    def setup_aws_k8s_cloud(self, region: str, name: str, yes: bool) -> None:
+        confirm(
+            "\nYou are about to give Anyscale access to EC2, EKS, and IAM "
+            "in your AWS account.\n\nContinue?",
+            yes,
+        )
+
+        # Create cloud in DB.
+        account_id = boto3.client("sts").get_caller_identity()["Account"]
+        cloud_response: CloudResponse = self.api_client.create_cloud_api_v2_clouds_post(
+            write_cloud=WriteCloud(
+                name=name,
+                provider=CloudProviders.AWS,
+                region=region,
+                credentials=account_id,
+                is_k8s=True,
+                is_aioa=False,
+            )
+        )
+        created_cloud: Cloud = cloud_response.result
+
+        # Grant Anyscale access.
+        cloud_credentials = json.loads(created_cloud.credentials)
+        # TODO: this should ideally be a model, but we don't expose this one in the client.
+        if not isinstance(cloud_credentials, dict):
+            raise TypeError("unable to interpret credentials of created cloud")
+        access_role_arn = cloud_credentials.get("customer_cloud_access_role_arn")
+        if not isinstance(access_role_arn, str):
+            raise TypeError(f"invalid access role in created cloud: {access_role_arn}")
+        _, _, access_role_name = access_role_arn.partition("/")
+        if not access_role_name:
+            raise ValueError("no access role name in credentials for created cloud")
+        anyscale_role_arn = cloud_credentials.get("anyscale_cloud_access_role_arn")
+        if not isinstance(anyscale_role_arn, str):
+            raise TypeError(
+                f"invalid Anyscale role in created cloud: {anyscale_role_arn}"
+            )
+        iam = _resource(name="iam", region=region)
+        for _ in range(ROLE_CREATION_RETRIES):
+            try:
+                role = iam.create_role(
+                    RoleName=access_role_name,
+                    AssumeRolePolicyDocument=json.dumps(
+                        {
+                            "Version": "2012-10-17",
+                            "Statement": {
+                                "Sid": "1",
+                                "Effect": "Allow",
+                                "Principal": {"AWS": anyscale_role_arn},
+                                "Action": "sts:AssumeRole",
+                                "Condition": {
+                                    "StringEquals": {"sts:ExternalId": created_cloud.id}
+                                },
+                            },
+                        }
+                    ),
+                )
+            except botocore.exceptions.ClientError:
+                time.sleep(ROLE_CREATION_INTERVAL_SECONDS)
+                continue
+            else:
+                break
+        anyscale_iam_policy = iam.Policy(
+            arn=f"arn:aws:iam::{account_id}:policy/{ANYSCALE_IAM_ACCESS_POLICY_NAME}"
+        )
+        try:
+            anyscale_iam_policy.load()
+        except botocore.exceptions.ClientError as exc:
+            if exc.response.get("Error", {}).get("Code") != "NoSuchEntity":
+                raise
+            anyscale_iam_policy = iam.create_policy(
+                PolicyName="AnyscaleIAMAccess",
+                PolicyDocument=json.dumps(ANYSCALE_IAM_ACCESS_POLICY_DOCUMENT),
+            )
+        eks_full_access_policy = iam.Policy(
+            arn=f"arn:aws:iam::{account_id}:policy/{EKS_FULL_ACCESS_POLICY_NAME}"
+        )
+        try:
+            eks_full_access_policy.load()
+        except botocore.exceptions.ClientError as exc:
+            if exc.response.get("Error", {}).get("Code") != "NoSuchEntity":
+                raise
+            eks_full_access_policy = iam.create_policy(
+                PolicyName="EKSFullAccess",
+                PolicyDocument=json.dumps(EKS_FULL_ACCESS_POLICY_DOCUMENT),
+                Description="This policy gives the role full access to EKS.",
+            )
+        role.attach_policy(PolicyArn=anyscale_iam_policy.arn)
+        role.attach_policy(PolicyArn=eks_full_access_policy.arn)
+        role.attach_policy(PolicyArn=AMAZON_VPC_FULL_ACCESS_POLICY_ARN)
+        role.attach_policy(PolicyArn=AMAZON_EC2_FULL_ACCESS_POLICY_ARN)
+        role.attach_policy(PolicyArn=AMAZON_CLOUDWATCH_FULL_ACCESS_POLICY_ARN)
+        role.attach_policy(PolicyArn=AMAZON_ROUTE53_FULL_ACCESS_POLICY_ARN)
+
+        self.log.info(
+            "Cloud creation in progress. Your cloud should be available in 20-30 minutes."
+        )
+        self.log.info(
+            f"If you want to remove this cloud, run `anyscale cloud delete -n {name}."
+        )
+        self.log.warning(
+            f"If you delete the role {access_role_name} without deleting the cloud, there "
+            "might remain resources running in your account."
+        )
+
     def update_cloud_config(
         self,
         cloud_name: Optional[str],
