@@ -1,4 +1,5 @@
 from datetime import datetime
+import os
 from typing import Any, Dict, Optional, Tuple
 
 import click
@@ -38,7 +39,7 @@ from anyscale.sdk.anyscale_client.models.create_cluster_compute import (
     CreateClusterCompute,
 )
 from anyscale.shared_anyscale_utils.util import slugify
-from anyscale.util import get_endpoint, wait_for_session_start
+from anyscale.util import get_endpoint, PROJECT_NAME_ENV_VAR, wait_for_session_start
 
 
 class ClusterController(BaseController):
@@ -288,6 +289,7 @@ class ClusterController(BaseController):
         Get cluster name and project id. If cluster id is specified, any cluster can
         be started (including outside the current or specified project).
         """
+        project_name = project_name or os.environ.get(PROJECT_NAME_ENV_VAR)
         if cluster_id:
             try:
                 cluster = self.anyscale_api_client.get_cluster(cluster_id).result
@@ -303,8 +305,19 @@ class ClusterController(BaseController):
                 project_id = get_proj_id_from_name(project_name, self.api_client)
             else:
                 try:
+                    # .anyscale.yaml detected in root directory and has correct format
                     project_definition = load_project_or_throw()
                     project_id = get_project_id(project_definition.root)
+                    project_name = self.anyscale_api_client.get_project(
+                        project_id
+                    ).result.name
+                    self.log.warning(
+                        ".anyscale.yaml has been detected in this project directory. The functionality of "
+                        "using this file to select the project has been deprecated, and will be removed "
+                        f"in April 2022. Please instead specify `--project-id {project_id}` in your command. "
+                        "The project name can also be specified by setting the environment variable "
+                        f'`{PROJECT_NAME_ENV_VAR}="{project_name}"`.'
+                    )
                 except click.ClickException:
                     default_project = (
                         self.anyscale_api_client.get_default_project().result
