@@ -3,13 +3,14 @@ import os
 from typing import Optional
 
 import click
+from openapi_client.rest import ApiException
 import tabulate
 
 import anyscale
 from anyscale.cli_logger import BlockLogger
 from anyscale.cloud import get_cloud_id_and_name
 from anyscale.controllers.base_controller import BaseController
-from anyscale.project import (
+from anyscale.project import (  # pylint:disable=private-import
     _write_project_file_to_disk,
     attach_to_project_with_id,
     create_new_proj_def,
@@ -56,6 +57,41 @@ class ProjectController(BaseController):
             project_id=project_id,
         )
 
+    def create(self, name: str) -> None:
+        """
+        Call API to create a new project given a project name.
+        """
+        existing_projects = []
+        try:
+            user_info = self.api_client.get_user_info_api_v2_userinfo_get()
+            existing_projects = self.api_client.find_project_by_project_name_api_v2_projects_find_by_name_get(
+                name, owner=user_info.result.username
+            ).results
+        except (click.ClickException, ApiException):
+            pass
+
+        if len(existing_projects):
+            project_id = existing_projects[0].id
+            url = get_endpoint(f"/projects/{project_id}")
+            self.log.info(
+                f"Project with name {name} is already created by you at {url}."
+            )
+        else:
+            # Create new project
+            project_id = self.api_client.create_project_api_v2_projects_post(
+                write_project={
+                    "name": name,
+                    "description": "",
+                    "initial_cluster_config": None,
+                }
+            ).result.id
+            url = get_endpoint(f"/projects/{project_id}")
+            self.log.info(f"Created project with name {name} at {url}.")
+        self.log.info(
+            f"Please specify the project id as {project_id} when calling "
+            "Anyscale CLI or SDK commands or Ray Client."
+        )
+
     def init(
         self,
         project_id: Optional[str],
