@@ -2,6 +2,7 @@ import sys
 from time import sleep, time
 from typing import Any, Dict, Optional
 
+from anyscale.api import configure_tcp_keepalive
 import anyscale.sdk.anyscale_client as anyscale_client
 from anyscale.sdk.anyscale_client.api.default_api import DefaultApi
 from anyscale.version import __version__ as version
@@ -32,6 +33,7 @@ class AnyscaleSDK(DefaultApi):  # type: ignore
         api_client = anyscale_client.ApiClient(
             configuration, cookie=f"cli_token={auth_token}"
         )
+        configure_tcp_keepalive(api_client)
         api_client.set_default_header(RequestHeaders.CLIENT, "SDK")
         api_client.set_default_header(RequestHeaders.CLIENT_VERSION, version)
         self.log: BlockLogger = BlockLogger()
