@@ -6,11 +6,11 @@ import aioredis
 from terminado import NamedTermManager, TermSocket
 import tornado.web
 
+from anyscale.shared_anyscale_utils.utils.id_gen import generate_id, IDTypes
 from anyscale.webterminal.command_persister import CommandPersister
 from anyscale.webterminal.utils import (
     EXEC_ZSH_CMD,
     extract_commands,
-    generate_id,
     log_commands,
     write_zshrc,
 )
@@ -35,7 +35,8 @@ class AnyscaleTermManager(NamedTermManager):  # type: ignore
         self.terminal_state: Dict[str, TermState] = {}
 
     def clean_up_terminal(self, term_name: str) -> None:
-        del self.terminals[term_name]
+        if term_name in self.terminals:
+            del self.terminals[term_name]
         del self.terminal_state[term_name]
         del self.is_debugger[term_name]
         del self.is_exec_command[term_name]
@@ -117,7 +118,8 @@ class AnyscaleTermManager(NamedTermManager):  # type: ignore
                     if last_command.finished:
                         # If the terminal is a single command terminal and the command is finished
                         # we can clean up the terminal.
-                        self.terminate(ptywclients.term_name, force=True)
+                        loop = tornado.ioloop.IOLoop.current()
+                        loop.spawn_callback(self.terminate, ptywclients.term_name, True)
                         self.clean_up_terminal(ptywclients.term_name)
             # Mark the command as either WT or SDK
             log_commands(commands)
@@ -153,10 +155,10 @@ class AnyscaleTermSocket(TermSocket):  # type: ignore
 class TerminalPageHandler(tornado.web.RequestHandler):
     """Render the /ttyX pages"""
 
-    def delete(self, term_name: str) -> None:
+    async def delete(self, term_name: str) -> None:
         term_manager = self.application.settings["term_manager"]
         command_persister = self.application.settings["command_persister"]
-        term_manager.terminate(term_name, force=True)
+        await term_manager.terminate(term_name, force=True)
         command_persister.kill_running_commands_for_terminal(term_name)
         term_manager.clean_up_terminal(term_name)
 
@@ -233,7 +235,7 @@ class ExecTerminalHandler(tornado.web.RequestHandler):
         shell_command = self.request.body_arguments.get("shell_command")
         command_id = self.request.body_arguments.get("command_id")
         term_manager = self.application.settings["term_manager"]
-        term_id = generate_id()
+        term_id = generate_id(IDTypes.session_commands)
         term = term_manager.get_terminal(
             term_id, is_debugger=False, exec_command_id=command_id
         )
