@@ -2,15 +2,18 @@ import json
 import os
 from pathlib import Path
 import tempfile
-from typing import Any, Dict, Optional
+import time
+from typing import Any, Dict, List, Optional, Tuple
 from unittest.mock import Mock, mock_open, patch
 
 import click
 import pytest
 import yaml
 
+from anyscale.cli_logger import BlockLogger
 from anyscale.client.openapi_client import CreateProductionJob, ProductionJobConfig
-from anyscale.controllers.job_controller import JobConfig, JobController
+from anyscale.controllers.job_controller import JobConfig, JobController, LogProvider
+from anyscale.util import PROJECT_NAME_ENV_VAR
 
 
 CONDA_DICT = {"dependencies": ["pip", {"pip": ["pip-install-test==0.5"]}]}
@@ -261,6 +264,9 @@ def test_terminate_job(
     job_controller.api_client.list_decorated_jobs_api_v2_decorated_ha_jobs_get = Mock(
         return_value=Mock(results=[Mock(id="mock_job_id")])
     )
+    job_controller.api_client.get_job_api_v2_decorated_ha_jobs_production_job_id_get = Mock(
+        return_value=Mock(result=Mock(id="mock_job_id"))
+    )
     if not name and not id:
         with pytest.raises(click.ClickException):
             job_controller.terminate(id, name, is_service)
@@ -435,8 +441,11 @@ class TestValidatePyModules:
 
 @pytest.mark.parametrize("project_id", [None, "proj_id"])
 @pytest.mark.parametrize("project_name", [None, "proj_name"])
+@pytest.mark.parametrize("project_name_env_var", [None, "proj_name_env"])
 def test_validate_project_id_field(
-    project_id: Optional[str], project_name: Optional[str]
+    project_id: Optional[str],
+    project_name: Optional[str],
+    project_name_env_var: Optional[str],
 ):
     mock_get_proj_id_from_name = Mock(return_value="proj_id")
     mock_validate_successful_build = Mock()
@@ -447,18 +456,103 @@ def test_validate_project_id_field(
         "project_id": project_id,
         "project": project_name,
     }
+    mock_os_dict = (
+        {PROJECT_NAME_ENV_VAR: project_name_env_var} if project_name_env_var else {}
+    )
     with patch.multiple(
         "anyscale.controllers.job_controller",
         get_proj_id_from_name=mock_get_proj_id_from_name,
         validate_successful_build=mock_validate_successful_build,
-    ):
+    ), patch.dict(os.environ, mock_os_dict):
         if project_id and project_name:
             with pytest.raises(click.ClickException):
                 job_config = JobConfig.parse_obj(config_dict)
         else:
             job_config = JobConfig.parse_obj(config_dict)
-            if project_name:
+            if project_name_env_var:
+                assert job_config.project_id == "proj_id"
+                mock_get_proj_id_from_name.assert_called_once_with(project_name_env_var)
+            elif project_name:
                 assert job_config.project_id == "proj_id"
                 mock_get_proj_id_from_name.assert_called_once_with(project_name)
             else:
                 assert job_config.project_id == project_id
+
+
+@pytest.mark.parametrize("mode", ["empty", "single", "paginate", "follow"])
+def test_job_logs(mock_auth_api_client, capsys, mode) -> None:
+    class FakeLogProvider(LogProvider):
+        def __init__(self, *args, **kwargs) -> None:
+            self.constructed_at = int(time.time() * 1e9)
+            self.page = -1
+            self.query_count = 0
+
+        def query(
+            self, start_timestamp_ns: int, end_timestamp_ns: int
+        ) -> List[Tuple[int, str]]:
+            # For typing
+            empty_list: List[Tuple[int, str]] = []
+
+            if mode == "empty":
+                return empty_list
+            if mode == "single":
+                if start_timestamp_ns > self.constructed_at:
+                    return []
+                return [(start_timestamp_ns, "start"), (self.constructed_at, "end")]
+            if mode == "paginate":
+                self.page += 1
+                return [
+                    [(start_timestamp_ns, "entry-1")],
+                    [(start_timestamp_ns + 1, "entry-2")],
+                    empty_list,
+                ][self.page]
+            if mode == "follow":
+                self.page += 1
+                return [
+                    # simulate no log
+                    empty_list,
+                    empty_list,
+                    [(start_timestamp_ns, "finally")],
+                ][self.page]
+
+            raise Exception("unreachable")
+
+    class FakeLogger(BlockLogger):
+        def open_block(
+            self, _block_label: str, _block_title: Optional[str] = None
+        ) -> None:
+            pass
+
+    job_controller = JobController(log=FakeLogger())
+    job_controller.anyscale_api_client.get_job_logs_query_info = Mock(
+        return_value=Mock(
+            result=Mock(
+                loki_dns_name="abc.com",
+                access_token="secret-key",
+                loki_query="query-abc",
+            )
+        )
+    )
+
+    def do_logs() -> None:
+        job_controller.logs(
+            job_id="mock_job_id",
+            job_name=None,
+            should_follow=mode == "follow",
+            log_provider_cls=FakeLogProvider,
+        )
+
+    if mode == "empty":
+        do_logs()
+        assert capsys.readouterr().out.strip() == ""
+    if mode == "single":
+        do_logs()
+        assert capsys.readouterr().out.strip() == "start\nend"
+    if mode == "paginate":
+        do_logs()
+        assert capsys.readouterr().out.strip() == "entry-1\nentry-2"
+    if mode == "follow":
+        with pytest.raises(IndexError):  # controller should continue to query
+            do_logs()
+        out = capsys.readouterr().out.strip()
+        assert out == "finally"
