@@ -1,6 +1,5 @@
 from datetime import datetime, timezone
 import json
-import os
 import tempfile
 from typing import Iterator, Optional, Tuple
 from unittest.mock import ANY, call, MagicMock, Mock, mock_open, patch
@@ -875,194 +874,6 @@ def test_ssh_session(
         )
 
 
-def test_autopush(
-    session_test_data: Session, mock_auth_api_client_with_session
-) -> None:
-
-    mock_project_definition = Mock()
-    mock_project_definition.root = "/some/directory"
-    mock_load_project_or_throw = Mock(return_value=mock_project_definition)
-    mock_get_project_id = Mock(return_value=session_test_data.project_id)
-    mock_get_project_session = Mock(return_value=session_test_data)
-    cluster_config_data = {"auth": {"ssh_user": "", "ssh_private_key": ""}}
-    mock_get_cluster_config = Mock(return_value=cluster_config_data)
-    mock_wait_for_session_start = Mock()
-    mock_get_working_dir = Mock(return_value="")
-    mock_managed_autosync_session = Mock()
-    mock_managed_autosync_session.return_value.__enter__ = Mock(
-        return_value=(Mock(), None)
-    )
-    mock_managed_autosync_session.return_value.__exit__ = Mock(return_value=None)
-    mock_perform_autopush_synchronization = Mock()
-    mock_perform_sync = Mock()
-    mock_perform_sync.return_value.returncode = 0
-
-    session_controller = SessionController()
-    session_controller.api_client.get_session_head_ip_api_v2_sessions_session_id_head_ip_get.return_value.result.head_ip = (
-        "127.0.0.1"
-    )
-
-    with patch.multiple(
-        "anyscale.controllers.session_controller",
-        load_project_or_throw=mock_load_project_or_throw,
-        get_project_id=mock_get_project_id,
-        get_cluster_config=mock_get_cluster_config,
-        get_project_session=mock_get_project_session,
-        get_working_dir=mock_get_working_dir,
-        managed_autosync_session=mock_managed_autosync_session,
-        perform_sync=mock_perform_sync,
-        wait_for_session_start=mock_wait_for_session_start,
-        perform_autopush_synchronization=mock_perform_autopush_synchronization,
-    ):
-        session_controller.autopush(session_name=session_test_data.name)
-
-    session_controller.api_client.get_session_head_ip_api_v2_sessions_session_id_head_ip_get.assert_called_once_with(
-        session_test_data.id,
-    )
-
-    mock_load_project_or_throw.assert_called_once_with()
-    mock_get_project_id.assert_called_once_with("/some/directory")
-    mock_get_project_session.assert_called_once_with(
-        session_test_data.project_id,
-        session_test_data.name,
-        session_controller.api_client,
-    )
-    mock_get_cluster_config.assert_called_once_with(
-        session_test_data.name, session_controller.api_client
-    )
-    mock_wait_for_session_start.assert_called_once_with(
-        session_test_data.project_id,
-        session_test_data.name,
-        session_controller.api_client,
-    )
-    mock_get_working_dir.assert_called_once_with(
-        cluster_config_data, session_test_data.project_id, session_controller.api_client
-    )
-    mock_managed_autosync_session.assert_called_once_with(
-        session_test_data.id, session_controller.api_client
-    )
-    mock_perform_sync.assert_called_once_with(
-        [
-            "ssh",
-            "-o",
-            "StrictHostKeyChecking=no",
-            "-o",
-            "UserKnownHostsFile={}".format(os.devnull),
-            "-o",
-            "LogLevel=ERROR",
-            "-i",
-            "",
-        ],
-        mock_project_definition.root,
-        "",
-        "127.0.0.1",
-        "",
-        False,
-        rsync_exclude=[],
-        rsync_filter=[],
-    )
-    mock_perform_autopush_synchronization.assert_called_once()
-
-
-def test_autosync_docker(
-    session_test_data: Session, mock_auth_api_client_with_session
-) -> None:
-
-    mock_project_definition = Mock()
-    mock_project_definition.root = "/some/directory"
-    mock_load_project_or_throw = Mock(return_value=mock_project_definition)
-    mock_get_project_id = Mock(return_value=session_test_data.project_id)
-    mock_get_project_session = Mock(return_value=session_test_data)
-    cluster_config_data = {"auth": {"ssh_user": "", "ssh_private_key": ""}}
-    cluster_config_data["docker"] = {
-        "image": "rayproject/ray:latest",
-        "container_name": "ray_container",
-    }
-    mock_get_cluster_config = Mock(return_value=cluster_config_data)
-    mock_wait_for_session_start = Mock()
-    mock_get_working_dir = Mock(return_value="/working_dir")
-    mock_managed_autosync_session = Mock()
-    mock_managed_autosync_session.return_value.__enter__ = Mock(
-        return_value=(Mock(), None)
-    )
-    mock_managed_autosync_session.return_value.__exit__ = Mock(return_value=None)
-    mock_perform_autopush_synchronization = Mock()
-    mock_perform_sync = Mock()
-    mock_perform_sync.return_value.returncode = 0
-
-    session_controller = SessionController()
-    session_controller.api_client.get_session_head_ip_api_v2_sessions_session_id_head_ip_get.return_value.result.head_ip = (
-        "127.0.0.1"
-    )
-
-    remote_location = "/fake/host/mount"
-    mock_subprocess_run = Mock()
-    mock_subprocess_run.return_value.stdout = json.dumps(
-        [{"Source": remote_location, "Destination": "/working_dir"}]
-    )
-
-    with patch.multiple(
-        "anyscale.controllers.session_controller",
-        load_project_or_throw=mock_load_project_or_throw,
-        get_project_id=mock_get_project_id,
-        get_cluster_config=mock_get_cluster_config,
-        get_project_session=mock_get_project_session,
-        get_working_dir=mock_get_working_dir,
-        managed_autosync_session=mock_managed_autosync_session,
-        perform_sync=mock_perform_sync,
-        wait_for_session_start=mock_wait_for_session_start,
-        perform_autopush_synchronization=mock_perform_autopush_synchronization,
-    ), patch.multiple("subprocess", run=mock_subprocess_run):
-        session_controller.autopush(session_name=session_test_data.name)
-
-    session_controller.api_client.get_session_head_ip_api_v2_sessions_session_id_head_ip_get.assert_called_once_with(
-        session_test_data.id,
-    )
-
-    mock_load_project_or_throw.assert_called_once_with()
-    mock_get_project_id.assert_called_once_with("/some/directory")
-    mock_get_project_session.assert_called_once_with(
-        session_test_data.project_id,
-        session_test_data.name,
-        session_controller.api_client,
-    )
-    mock_get_cluster_config.assert_called_once_with(
-        session_test_data.name, session_controller.api_client
-    )
-    mock_wait_for_session_start.assert_called_once_with(
-        session_test_data.project_id,
-        session_test_data.name,
-        session_controller.api_client,
-    )
-    mock_get_working_dir.assert_called_once_with(
-        cluster_config_data, session_test_data.project_id, session_controller.api_client
-    )
-    mock_managed_autosync_session.assert_called_once_with(
-        session_test_data.id, session_controller.api_client
-    )
-    mock_perform_sync.assert_called_once_with(
-        [
-            "ssh",
-            "-o",
-            "StrictHostKeyChecking=no",
-            "-o",
-            "UserKnownHostsFile={}".format(os.devnull),
-            "-o",
-            "LogLevel=ERROR",
-            "-i",
-            "",
-        ],
-        mock_project_definition.root,
-        "",
-        "127.0.0.1",
-        remote_location,
-        False,
-        rsync_exclude=[],
-        rsync_filter=[],
-    )
-    mock_perform_autopush_synchronization.assert_called_once()
-
-
 def test_anyscale_push_session(
     session_test_data: Session, mock_auth_api_client_with_session
 ) -> None:
@@ -1073,11 +884,6 @@ def test_anyscale_push_session(
     mock_get_project_session = Mock(return_value=session_test_data)
     cluster_config_data = {"auth": {"ssh_user": "", "ssh_private_key": ""}}
     mock_get_cluster_config = Mock(return_value=cluster_config_data)
-    mock_managed_autosync_session = Mock()
-    mock_managed_autosync_session.return_value.__enter__ = Mock(
-        return_value=(Mock(), None)
-    )
-    mock_managed_autosync_session.return_value.__exit__ = Mock(return_value=None)
     mock_subprocess_run = Mock()
     mock_subprocess_run.return_value.returncode = 0
 
