@@ -20,7 +20,7 @@ from anyscale.cluster_config import (
     _configure_ssh_key,
     _update_file_mounts,
 )
-from anyscale.project import CLUSTER_YAML_TEMPLATE
+from anyscale.shared_anyscale_utils.project import CLUSTER_YAML_TEMPLATE
 
 
 def test_configure_cluster_name(base_mock_api_client: Mock) -> None:
@@ -108,9 +108,7 @@ def test_update_file_mounts_if_proj_dir_exists(config_patches: str) -> None:
     project_usr2_root_dir = "/home/usr2/root/dir"
     remote_project_directory_name = f"/home/ray/{config_patches}"
 
-    mock_path_exists = Mock(
-        side_effect=lambda x: True if x == project_usr2_root_dir else False
-    )
+    mock_path_exists = Mock(side_effect=lambda x: x == project_usr2_root_dir)
     mock_path_samefile = Mock(side_effect=lambda x, y: x == y)
 
     with patch.multiple(
