@@ -1,9 +1,13 @@
-from typing import Any
+from typing import Any, Dict
 from unittest.mock import patch
 
 import pytest
 
-from anyscale.util import _update_external_ids_for_policy, updating_printer
+from anyscale.util import (
+    _update_external_ids_for_policy,
+    number_of_external_ids_in_policy,
+    updating_printer,
+)
 
 
 def test_updating_printer() -> None:
@@ -140,3 +144,44 @@ def test_update_external_ids_for_policy(statement_policy, expected_conditions):
 
     for new, expected in zip(new_policy["Statement"], expected_conditions):
         assert new["Condition"] == expected
+
+
+@pytest.mark.parametrize(
+    "statement,num_ext_ids",
+    [
+        pytest.param(
+            [STATEMENT_TEMPLATE, STATEMENT_TEMPLATE],
+            0,
+            id="MultipleStatements,NoExtID",
+        ),
+        pytest.param(
+            [
+                {
+                    "Condition": {"StringEquals": {"sts:ExternalId": "old_id"}},
+                    **STATEMENT_TEMPLATE,  # type: ignore
+                },
+                STATEMENT_TEMPLATE,
+            ],
+            1,
+            id="OneExternalID,MultipleStatements",
+        ),
+        pytest.param(
+            [
+                {
+                    "Condition": {
+                        "StringEquals": {"sts:ExternalId": ["id_one", "id_two"]}
+                    },
+                    **STATEMENT_TEMPLATE,  # type: ignore
+                }
+            ],
+            2,
+            id="ExternalIdList",
+        ),
+    ],
+)
+def test_number_of_external_ids_in_policy(statement: Dict[str, Any], num_ext_ids: int):
+    policy = {
+        "Statement": statement,
+        "Version": "2012-10-17",
+    }
+    assert number_of_external_ids_in_policy(policy) == num_ext_ids
